// cc-by 3.0 Austria, (c) 2010 Markus Loeberbauer
// http://ssw.jku.at/Teaching/Lectures/SpezialLVA/JavaFX/
// based on http://code.google.com/appengine/docs/java/gettingstarted/

package guestbook;

import java.io.IOException;
import java.util.List;

import javax.jdo.PersistenceManager;
import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.google.appengine.api.users.User;
import com.google.appengine.api.users.UserService;
import com.google.appengine.api.users.UserServiceFactory;

public class GuestbookServlet extends HttpServlet {
	private static final long serialVersionUID = 1L;

	public void doGet(HttpServletRequest req, HttpServletResponse resp)
			throws IOException, ServletException {
		User user = authenticateUser(req, resp);
		if (user != null) {
			showGuestbook(req, resp, user);
		}
	}

	private User authenticateUser(HttpServletRequest req,
			HttpServletResponse resp) throws IOException {
		UserService userService = UserServiceFactory.getUserService();
		User user = userService.getCurrentUser();

		if (user == null) {
			resp.sendRedirect(userService.createLoginURL(req.getRequestURI()));
		}

		return user;
	}

	private void showGuestbook(HttpServletRequest req,
			HttpServletResponse resp, User user) throws ServletException,
			IOException {
		req.setAttribute("user", user);
		req.setAttribute("greetings", getGreetings());
		req.setAttribute("logoutUrl", createLogoutUrl());

		RequestDispatcher rd = getServletContext().getRequestDispatcher(
				resp.encodeURL("/WEB-INF/JSP/guestbook.jsp"));
		rd.forward(req, resp);
	}

	private List<Greeting> getGreetings() {
		PersistenceManager pm = PersistenceManagerFactoryProvider.get()
				.getPersistenceManager();
		String query = "select from " + Greeting.class.getName()
				+ " order by date desc range 0,5";
		@SuppressWarnings("unchecked")
		List<Greeting> greetings = (List<Greeting>) pm.newQuery(query)
				.execute();
		return greetings;
	}

	private String createLogoutUrl() {
		return UserServiceFactory.getUserService().createLogoutURL(
				"http://www.google.com");
	}

}
